@@ -458,7 +458,7 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
 		if ftpItem.isDir():
 			if ftpItem.name() != ".":
 				self.isRemoteDirectory[ftpItem.name()]=ftpItem.isDir()
-				self.m_lw_remote.addItem(QListWidgetItem(QIcon("ressource/folder.xpm"), ftpItem.name(), self.m_lw_remote))
+				self.m_lw_remote.addItem(QListWidgetItem(QIcon("/opt/n900ftp/ressource/folder.xpm"), ftpItem.name(), self.m_lw_remote))
 		else :
 			self.m_lw_remote.addItem(ftpItem.name())
     
@@ -487,7 +487,7 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
 			if i == "..":
 				self.m_lw_local.addItem(i)
 			elif i != ".":
-				self.m_lw_local.addItem(QListWidgetItem(QIcon("ressource/folder.xpm"), i, self.m_lw_local))
+				self.m_lw_local.addItem(QListWidgetItem(QIcon("/opt/n900ftp/ressource/folder.xpm"), i, self.m_lw_local))
 				self.isLocalDirectory[i]=1
 
 		#now the normal files are added
